@@ -19,14 +19,17 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -51,6 +54,8 @@ class DataFusionAsyncClient:
     DEFAULT_ENDPOINT = DataFusionClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = DataFusionClient.DEFAULT_MTLS_ENDPOINT
 
+    crypto_key_path = staticmethod(DataFusionClient.crypto_key_path)
+    parse_crypto_key_path = staticmethod(DataFusionClient.parse_crypto_key_path)
     instance_path = staticmethod(DataFusionClient.instance_path)
     parse_instance_path = staticmethod(DataFusionClient.parse_instance_path)
     common_billing_account_path = staticmethod(
@@ -373,8 +378,8 @@ class DataFusionAsyncClient:
                 The request object. Request message for creating a Data
                 Fusion instance.
             parent (:class:`str`):
-                The instance's project and location
-                in the format
+                Required. The instance's project and
+                location in the format
                 projects/{project}/locations/{location}.
 
                 This corresponds to the ``parent`` field
@@ -386,7 +391,9 @@ class DataFusionAsyncClient:
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             instance_id (:class:`str`):
-                The name of the instance to create.
+                Required. The name of the instance to
+                create.
+
                 This corresponds to the ``instance_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -470,8 +477,8 @@ class DataFusionAsyncClient:
                 The request object. Request message for deleting a Data
                 Fusion instance.
             name (:class:`str`):
-                The instance resource name in the
-                format
+                Required. The instance resource name
+                in the format
                 projects/{project}/locations/{location}/instances/{instance}
 
                 This corresponds to the ``name`` field
@@ -561,14 +568,17 @@ class DataFusionAsyncClient:
 
         Args:
             request (Union[google.cloud.data_fusion_v1.types.UpdateInstanceRequest, dict]):
-                The request object.
+                The request object. Request message for updating a Data
+                Fusion instance. Data Fusion allows updating the labels,
+                options, and stack driver settings. This is also used
+                for CDF version upgrade.
             instance (:class:`google.cloud.data_fusion_v1.types.Instance`):
-                The instance resource that replaces
-                the resource on the server. Currently,
-                Data Fusion only allows replacing
-                labels, options, and stack driver
-                settings. All other fields will be
-                ignored.
+                Required. The instance resource that
+                replaces the resource on the server.
+                Currently, Data Fusion only allows
+                replacing labels, options, and stack
+                driver settings. All other fields will
+                be ignored.
 
                 This corresponds to the ``instance`` field
                 on the ``request`` instance; if ``request`` is provided, this
